@@ -42,11 +42,18 @@
 #define CYAN       6
 #define	WHITE      7
 
-void set_colorize(int in);
-void colorize(int attribute, int foreground, int background, gchar *str);
-void colorize_fg(int attribute, int foreground, gchar *str);
-void colorize_attr(int attribute, gchar *str);
-void colorize_reset(gchar *str);
-gchar* string_color_of(int color);
+
+void colorize_xterm_title(gchar *title);
+void set_colorize(const int in);
+void colorize_fg(const int attribute, const int foreground);
+void colorize_reset(void);
+void colorize_bright(void);
+void colorize_error(void);
+gchar* string_color_of(const int color);
 int int_color_of(gchar* string);
+
+#ifdef CURSES
+extern WINDOW *pal_curwin;
+#endif
+
 #endif
