@@ -3,7 +3,7 @@
 
 /* pal
  *
- * Copyright (C) 2004, Scott Kuhl
+ * Copyright (C) 2004--2006, Scott Kuhl
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,5 +21,8 @@
  *
  */
 
-void pal_edit_event();
+#include "main.h"
+
+gchar* pal_edit_desc(gchar* text);
+void pal_edit_event(PalEvent* event, GDate *d);
 #endif
