@@ -22,8 +22,7 @@
  */
 
 
-GHashTable* load_files();
-gboolean pal_input_file_is_global(const gchar* filename);
+GHashTable* load_files(void);
 void pal_input_skip_comments(FILE* file, FILE* out_file);
 PalEvent* pal_input_read_head(FILE* file, FILE* out_file, gchar* filename);
 PalEvent* pal_input_read_event(FILE* file, FILE* out_file, gchar* filename, PalEvent* event_head, PalEvent* del_event);
