@@ -23,6 +23,6 @@
 
 
 
-void pal_latex_out();
+void pal_latex_out(void);
 
 #endif
