@@ -21,19 +21,20 @@
  *
  */
 
-#include <glib.h>
 #include "main.h"
 
 #include "colorize.h"
 
+void pal_output_handler( const gchar *instr );
+
 void pal_output_attr(gint attr, gchar *formatString, ...);
-void pal_output_fg( gint attr, gint color, gchar *formatString,...);
+void pal_output_fg(gint attr, gint color, gchar *formatString,...);
 void pal_output_error(char *formatString, ... );
 
-void pal_output_cal(GDate* date, gint num_weeks, GDate* today);
-void pal_output_date(GDate* date, gboolean show_empty_days, gboolean number_events);
+void pal_output_cal(gint num_weeks, GDate* today);
+int pal_output_date(GDate* date, gboolean show_empty_days, gint select_event);
 void pal_output_date_line(GDate* date);
-void pal_output_event(PalEvent* event, GDate* date, gint event_number);
-void pal_output_wrap(const gchar* string, gint chars_used, gint indent);
+int pal_output_event(PalEvent* event, GDate* date, gboolean selected);
+int pal_output_wrap(const gchar* string, gint chars_used, gint indent);
 PalEvent* pal_output_event_num(const GDate* date, gint event_number);
 #endif
